/* \file WriteData.c:
 * \brief: general interface for writing data
 */

#ifdef HAVE_CONFIG_H
	#include <config.h>
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#define PY_ARRAY_UNIQUE_SYMBOL PythonIOSymbol
#define NO_IMPORT

#include "../../toolkits/toolkits.h"
#include "../../include/include.h"
#include "../../modules/modules.h"
#include "../../Container/Container.h"
#include "../../shared/shared.h"
#include "../../io/io.h"
#include "../../EnumDefinitions/EnumDefinitions.h"

/*Primitive data types*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,int integer){{{*/
void WriteData(PyObject* py_tuple, int index, int integer){
	
	PyTuple_SetItem(py_tuple, index, PyInt_FromSsize_t(integer));

}/*}}}*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,char* string){{{*/
void WriteData(PyObject* py_tuple, int index, char* string){
	
	PyTuple_SetItem(py_tuple, index, PyUnicode_FromString(string));

}/*}}}*/
/*FUNCTION WriteData(PyObject* py_tuple,int index, double* matrix, int M, int N){{{*/
void WriteData(PyObject* tuple, int index, double* matrix, int M,int N){

	npy_intp dims[2]={0,0};
	PyObject* array=NULL;

	dims[0]=(npy_intp)M;
	dims[1]=(npy_intp)N;
	array=PyArray_SimpleNewFromData(2,dims,NPY_DOUBLE,matrix);

	PyTuple_SetItem(tuple, index, array);
}/*}}}*/

/*ISSM objects*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,BamgGeom* bamggeom){{{*/
void WriteData(PyObject* py_tuple,int index,BamgGeom* bamggeom){

	_error_("not implemented yes, see ../../matlab/io/WriteMatlabData.cpp");
}
/*}}}*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,BamgMesh* bamgmesh){{{*/
void WriteData(PyObject* py_tuple,int index,BamgMesh* bamgmesh){

	_error_("not implemented yes, see ../../matlab/io/WriteMatlabData.cpp");
}
/*}}}*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,SeqMat<double>* matrix){{{*/
void WriteData(PyObject* py_tuple,int index,SeqMat<double>* matrix){
	
	int M,N;
	double* buffer=NULL;
	npy_intp dims[2]={0,0};
	PyObject* array=NULL;
	
	buffer=matrix->ToSerial();
	matrix->GetSize(&M,&N);
	dims[0]=(npy_intp)M;
	dims[1]=(npy_intp)N;
	array=PyArray_SimpleNewFromData(2,dims,NPY_DOUBLE,buffer);
	
	PyTuple_SetItem(py_tuple, index, array);

}/*}}}*/
/*FUNCTION WriteData(PyObject* py_tuple,int index,SeqVec<double>* vector){{{*/
void WriteData(PyObject* tuple,int index,SeqVec<double>* vector){
	
	int M;
	double* buffer=NULL;
	npy_intp dim=10;
	PyObject* array=NULL;
	
	buffer=vector->ToMPISerial();
	vector->GetSize(&M);
	dim=(npy_intp)M;
	array=PyArray_SimpleNewFromData(1,&dim,NPY_DOUBLE,buffer);
	
	PyTuple_SetItem(tuple, index, array);
}
/*}}}*/
